normal

Function normal 

pub fn normal(text: impl Display) -> String
Prints normal text without any special styling. This can be used for messages that don’t fit into the other categories or when you want to reset back to default styling after a heading or label.