pub fn landing(version: &str)Expand description
Default landing output shown when running bond without subcommands.
TODO: This should automatically display the command list and descriptions, but for now it’s just a branded message with quick start instructions.